/*
Copyright (C) 2004 Patrice Tremblay <tremblaypatrice@yahoo.fr>

based on plastik:
Copyright (C) 2003 Sandro Giessl <ceebx@users.sourceforge.net>

based on the Keramik configuration dialog:
Copyright (c) 2003 Maksim Orlovich <maksim.orlovich@kdemail.net>

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.

*/

#include <qcheckbox.h>
#include <qlayout.h>
#include <qhbox.h>
#include <qsettings.h>
#include <qcolor.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <kglobal.h>
#include <klocale.h>
#include <kcolorbutton.h>
#include <qtabwidget.h>
#include <qvgroupbox.h>
#include <qgrid.h>

#include "lipstikconf.h"

extern "C"
{
	QWidget* allocate_kstyle_config(QWidget* parent)
	{
		KGlobal::locale()->insertCatalogue("kstyle_lipstik_config");
		return new LipstikStyleConfig(parent);
	}
}

LipstikStyleConfig::LipstikStyleConfig(QWidget* parent): QWidget(parent)
{
	QVBoxLayout* layout = new QVBoxLayout(this, 0, 0);
	QGridLayout* tabLayout = new QGridLayout(this, 2, 1, 10);

	KGlobal::locale()->insertCatalogue("kstyle_lipstik_config");

///Init tabs
	QTabWidget *tabWidget = new QTabWidget(this);
	layout->addWidget(tabWidget);

///Init tab1 
	QWidget *page1 = new QWidget(tabWidget);
        layout = new QVBoxLayout(page1);
	    
	tabWidget->insertTab(page1, i18n("Configuration"));
		
	layout->addLayout(tabLayout);	

///General group
	QVGroupBox *generalGrp = new QVGroupBox(i18n("General"), page1);
				
	reverseGradients = new QCheckBox(i18n("Inverted gradients (plastik style)"), generalGrp );
	drawTriangularExpander = new QCheckBox(i18n("Triangular tree expander"), generalGrp);
	drawStatusBarFrame = new QCheckBox(i18n("Draw status bar frames"), generalGrp);
	animateProgressBar = new QCheckBox(i18n("Animate progress bars"), generalGrp);
	drawFocusRect = new QCheckBox(i18n("Draw colored focus rectangle"), generalGrp);
	newKickerButtons = new QCheckBox(i18n("Flat taskbar buttons"), generalGrp);
	flatHeaders = new QCheckBox(i18n("Flat column headers"), generalGrp);

	tabLayout->addWidget(generalGrp,0,0,0);

///Menus group
	QVGroupBox *menusGrp = new QVGroupBox(i18n("Menus"), page1);

	sharperMenuGradient = new QCheckBox(i18n("Sharper menu gradients"), menusGrp);
	menuLeftSideBar = new QCheckBox(i18n("Menu left-side stripe"), menusGrp);

	customMenuStripeColor = new QCheckBox(i18n("Custom menu stripe color :"), menusGrp);
	QHBox *menuColorBox = new QHBox(menusGrp);
	menuColorBox->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
	menuStripeColor = new KColorButton(menuColorBox);

	tabLayout->addWidget(menusGrp,0,1,0);

///Toolbar group
	QVGroupBox *toolbarGrp = new QVGroupBox(i18n("Toolbars"), page1);

	drawToolBarSeparator = new QCheckBox(i18n("Draw toolbar separators"), toolbarGrp);
	drawToolBarItemSeparator = new QCheckBox(i18n("Draw toolbar item separators"), toolbarGrp);
	drawToolBarHandle = new QCheckBox(i18n("Draw toolbar handles"), toolbarGrp);
	largeGap = new QCheckBox(i18n("Larger space between items"), toolbarGrp);
//	useAlterHandle = new QCheckBox(i18n("Alternate handle style"), toolbarGrp);

	tabLayout->addWidget(toolbarGrp,1,0,0);	

///Scrollbar group
	QVGroupBox *scrollGrp = new QVGroupBox(i18n("Scrollbars and Sliders"), page1);
	QLabel* scrollBarStyleLabel;
	QLabel* sliderStyleLabel;

	paintGroove = new QCheckBox(i18n("Draw scrollbar grooves"), scrollGrp);

        scrollBarStyleLabel = new QLabel(scrollGrp);
        scrollBarStyleLabel->setText(i18n("Scrollbar style :       "));
	scrollBarStyle = new QComboBox(i18n("Scrollbar style"), scrollGrp);
	scrollBarStyle->setEditable(false);
	scrollBarStyle->insertItem("Windows style");
	scrollBarStyle->insertItem("Platinum style");
	scrollBarStyle->insertItem("KDE style");
	scrollBarStyle->insertItem("Next style");

        sliderStyleLabel = new QLabel(scrollGrp);
        sliderStyleLabel->setText(i18n("Slider handle size :       "));
	sliderStyle = new QComboBox(i18n("Slider handle size"), scrollGrp);
	sliderStyle->setEditable(false);
	sliderStyle->insertItem("Small");
	sliderStyle->insertItem("Medium");
	sliderStyle->insertItem("Large");

	tabLayout->addWidget(scrollGrp,1,1,0);	

///Highlighting group
	QVGroupBox *lightGrp = new QVGroupBox(i18n("Highlighting"), page1);

	kickerHighlight = new QCheckBox(i18n("Highlight active taskbar button"), lightGrp);
	comboboxColored = new QCheckBox(i18n("Colored combobox handles"), lightGrp);
	inputFocusHighlight = new QCheckBox(i18n("Highlight focused text input fields"), lightGrp);

        customFocusHighlightColor = new QCheckBox(i18n("Custom text input fields highlight color :"), lightGrp);
	QHBox *hbox1 = new QHBox(lightGrp);
	hbox1->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
	focusHighlightColor = new KColorButton(hbox1);

	tabLayout->addWidget(lightGrp,0,2,0);	

///Other colors group
	QVGroupBox *otherGrp = new QVGroupBox(i18n("Other custom colors"), page1);
	
	customOverHighlightColor = new QCheckBox(i18n("Custom mouseover highlight color :"), otherGrp);
	QHBox *hbox2 = new QHBox(otherGrp);
	hbox2->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
	overHighlightColor = new KColorButton(hbox2);

	customCheckMarkColor = new QCheckBox(i18n("Custom checkmark/radiobuttons color :"), otherGrp);
	QHBox *hbox3 = new QHBox(otherGrp);
	hbox3->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
	checkMarkColor = new KColorButton(hbox3);

	tabLayout->addWidget(otherGrp,1,2,0);	

///Init tab2
	QWidget *page2 = new QWidget(tabWidget);
	QLabel* lipstikLabel;
	QLabel* authorLabel;
	QLabel* authorAddressLabel;
	QLabel* plastikLabel;
	QLabel* alsoLabel;
	QLabel* dnLabel;
	QLabel* pqLabel;
	QLabel* cxLabel;
	QLabel* kpLabel;
	QLabel* blLabel;
	QLabel* ksLabel;
	QLabel* othersLabel;

        layout = new QVBoxLayout(page2, 8, -1);
	    
	tabWidget->insertTab(page2, i18n("About"));

	lipstikLabel = new QLabel(page2);
        lipstikLabel->setText(i18n("Lipstik 1.3"));
	lipstikLabel->setFrameStyle( QFrame::StyledPanel | QFrame::Raised );

	authorLabel = new QLabel(page2);
        authorLabel->setText(i18n("     Copyright 2004-2005 (C) Patrice Tremblay [PaT]"));

	authorAddressLabel = new QLabel(page2);
        authorAddressLabel->setText(i18n("      tremblaypatrice@yahoo.fr"));

	plastikLabel = new QLabel(page2);
        plastikLabel->setText(i18n("Based on plastik [thanks to Sandro Giessl]"));

	alsoLabel = new QLabel(page2);
        alsoLabel->setText(i18n("Also based on :"));

	dnLabel = new QLabel(page2);
        dnLabel->setText(i18n("    DotNET [thanks to Chris Lee],"));

	pqLabel = new QLabel(page2);
        pqLabel->setText(i18n("    PlastikQ [thanks to Martin Beck],"));

	cxLabel = new QLabel(page2);
        cxLabel->setText(i18n("    Comix [thanks to Jens Luetkens],"));

	kpLabel = new QLabel(page2);
        kpLabel->setText(i18n("    Krisp [thanks to Keith Meehl],"));

	blLabel = new QLabel(page2);
        blLabel->setText(i18n("    Ballistik [thanks to Florian Merz],"));

	ksLabel = new QLabel(page2);
        ksLabel->setText(i18n("    Kerastik [thanks to Victor Perez Q]."));

	othersLabel = new QLabel(page2);
        othersLabel->setText(i18n("Special thanks to Dominique and all the kde-look.org users."));

	layout->add(lipstikLabel);
	layout->add(authorLabel);
	layout->add(authorAddressLabel);
	layout->addSpacing(10);

	layout->add(plastikLabel);
	layout->addSpacing(10);

	layout->add(alsoLabel);
	layout->add(dnLabel);
	layout->add(pqLabel);
	layout->add(cxLabel);
	layout->add(kpLabel);
	layout->add(blLabel);
	layout->add(ksLabel);
	layout->addSpacing(10);
	layout->add(othersLabel);

///Populate!
	QSettings s;
// 	origScrollBarLines = s.readBoolEntry("/lipstikstyle/Settings/scrollBarLines", false);
// 	scrollBarLines->setChecked(origScrollBarLines);
	origReverseGradients = s.readBoolEntry("/lipstikstyle/Settings/reverseGradients", false);
	reverseGradients->setChecked(origReverseGradients);

	origPaintGroove = s.readBoolEntry("/lipstikstyle/Settings/paintGroove", true);
	paintGroove->setChecked(origPaintGroove);

//	origUseAlterHandle = s.readBoolEntry("/lipstikstyle/Settings/useAlterHandle", false);
//	useAlterHandle->setChecked(origUseAlterHandle);

	origSharperMenuGradient = s.readBoolEntry("/lipstikstyle/Settings/sharperMenuGradient", false);
	sharperMenuGradient->setChecked(origSharperMenuGradient);
	origMenuLeftSideBar = s.readBoolEntry("/lipstikstyle/Settings/menuLeftSideBar", true);
	menuLeftSideBar->setChecked(origMenuLeftSideBar);
	origComboboxColored = s.readBoolEntry("/lipstikstyle/Settings/comboboxColored", false);
	comboboxColored->setChecked(origComboboxColored);
	origKickerHighlight = s.readBoolEntry("/lipstikstyle/Settings/kickerHighlight", true);
	kickerHighlight->setChecked(origKickerHighlight);

	origScrollBarStyle = s.readEntry("/lipstikstyle/Settings/scrollBarStyle", "WindowsStyleScrollBar");
	scrollBarStyle->setCurrentItem(scrollBarItem(origScrollBarStyle));

	origSliderStyle = s.readEntry("/lipstikstyle/Settings/sliderStyle", "sliderLipstikStyle");
	sliderStyle->setCurrentItem(sliderItem(origSliderStyle));

	origDrawStatusBarFrame = s.readBoolEntry("/lipstikstyle/Settings/drawStatusBarFrame", false);
	drawStatusBarFrame->setChecked(origDrawStatusBarFrame);
	origDrawToolBarHandle = s.readBoolEntry("/lipstikstyle/Settings/drawToolBarHandle", true);
	drawToolBarHandle->setChecked(origDrawToolBarHandle);

	origAnimProgressBar = s.readBoolEntry("/lipstikstyle/Settings/animateProgressBar", true);
	animateProgressBar->setChecked(origAnimProgressBar);
	origDrawToolBarSeparator = s.readBoolEntry("/lipstikstyle/Settings/drawToolBarSeparator", false);
	drawToolBarSeparator->setChecked(origDrawToolBarSeparator);
	origDrawToolBarItemSeparator = s.readBoolEntry("/lipstikstyle/Settings/drawToolBarItemSeparator", true);
	drawToolBarItemSeparator->setChecked(origDrawToolBarItemSeparator);

	origLargeGap = s.readBoolEntry("/lipstikstyle/Settings/largeGap", false);
	largeGap->setChecked(origLargeGap);

 	origDrawFocusRect = s.readBoolEntry("/lipstikstyle/Settings/drawFocusRect", false);
	drawFocusRect->setChecked(origDrawFocusRect);

 	origNewKickerButtons = s.readBoolEntry("/lipstikstyle/Settings/newKickerButtons", false);
	newKickerButtons->setChecked(origNewKickerButtons);

 	origFlatHeaders = s.readBoolEntry("/lipstikstyle/Settings/flatHeaders", false);
	flatHeaders->setChecked(origFlatHeaders);

	origDrawTriangularExpander = s.readBoolEntry("/lipstikstyle/Settings/drawTriangularExpander", true);
	drawTriangularExpander->setChecked(origDrawTriangularExpander);
	origInputFocusHighlight = s.readBoolEntry("/lipstikstyle/Settings/inputFocusHighlight", true);
	inputFocusHighlight->setChecked(origInputFocusHighlight);

	origCustomOverHighlightColor = s.readBoolEntry("/lipstikstyle/Settings/customOverHighlightColor", false);
	customOverHighlightColor->setChecked(origCustomOverHighlightColor);
	origOverHighlightColor = s.readEntry("/lipstikstyle/Settings/overHighlightColor", "black");
	overHighlightColor->setColor(origOverHighlightColor);

	origCustomMenuStripeColor = s.readBoolEntry("/lipstikstyle/Settings/customMenuStripeColor", false);
	customMenuStripeColor->setChecked(origCustomMenuStripeColor);
	origMenuStripeColor = s.readEntry("/lipstikstyle/Settings/menuStripeColor", "black");
	menuStripeColor->setColor(origMenuStripeColor);

	origCustomFocusHighlightColor = s.readBoolEntry("/lipstikstyle/Settings/customFocusHighlightColor", false);
	customFocusHighlightColor->setChecked(origCustomFocusHighlightColor);
	origFocusHighlightColor = s.readEntry("/lipstikstyle/Settings/focusHighlightColor", "black");
	focusHighlightColor->setColor(origFocusHighlightColor);
	origCustomCheckMarkColor = s.readBoolEntry("/lipstikstyle/Settings/customCheckMarkColor", false);
	customCheckMarkColor->setChecked(origCustomCheckMarkColor);
	origCheckMarkColor = s.readEntry("/lipstikstyle/Settings/checkMarkColor", "black");
	checkMarkColor->setColor(origCheckMarkColor);

// 	connect(scrollBarLines, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(reverseGradients, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	connect(paintGroove, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
//	connect(useAlterHandle, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(sharperMenuGradient, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(menuLeftSideBar, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawStatusBarFrame, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawToolBarHandle, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(comboboxColored, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(kickerHighlight, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	connect(scrollBarStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );
	connect(sliderStyle, SIGNAL( activated(int) ), SLOT( updateChanged() ) );

	connect(animateProgressBar, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(drawToolBarSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	connect(largeGap, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	connect(drawToolBarItemSeparator, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(drawFocusRect, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

 	connect(newKickerButtons, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
 	connect(flatHeaders, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );

	connect(drawTriangularExpander, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(inputFocusHighlight, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(customOverHighlightColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(overHighlightColor, SIGNAL( changed(QColor) ), SLOT( colorChanged() ) );

	connect(customMenuStripeColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(menuStripeColor, SIGNAL( changed(QColor) ), SLOT( colorChanged() ) );

	connect(customFocusHighlightColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(focusHighlightColor, SIGNAL( changed(QColor) ), SLOT( colorChanged() ) );
	connect(customCheckMarkColor, SIGNAL( toggled(bool) ), SLOT( updateChanged() ) );
	connect(checkMarkColor, SIGNAL( changed(QColor) ), SLOT( colorChanged() ) );

//Menu Stripe 
	if ( menuLeftSideBar->isChecked() ) {
	    customMenuStripeColor->setEnabled(true);
	} else {
	    customMenuStripeColor->setEnabled(false);
	}

	if ( customMenuStripeColor->isChecked() && customMenuStripeColor->isEnabled())
	 menuStripeColor->setEnabled(true);
	else
	 menuStripeColor->setEnabled(false);

//New Kicker Taskbar Button style
	if ( newKickerButtons->isChecked() ) {
	    kickerHighlight->setEnabled(false);
	}
    
//Input Focus 
	if ( inputFocusHighlight->isChecked() )
	    customFocusHighlightColor->setEnabled(true);
	else
	    customFocusHighlightColor->setEnabled(false);

	if ( customFocusHighlightColor->isChecked() && customFocusHighlightColor->isEnabled())
	 focusHighlightColor->setEnabled(true);
	else
	 focusHighlightColor->setEnabled(false);


	if ( customCheckMarkColor->isChecked() )
	 checkMarkColor->setEnabled(true);
	else
	 checkMarkColor->setEnabled(false);

	if ( customOverHighlightColor->isChecked() )
	 overHighlightColor->setEnabled(true);
	else
	 overHighlightColor->setEnabled(false);
}

LipstikStyleConfig::~LipstikStyleConfig()
{
}


void LipstikStyleConfig::save()
{
	QSettings s;
// 	s.writeEntry("/lipstikstyle/Settings/scrollBarLines", scrollBarLines->isChecked());
	s.writeEntry("/lipstikstyle/Settings/reverseGradients", reverseGradients->isChecked());

//	s.writeEntry("/lipstikstyle/Settings/useAlterHandle", useAlterHandle->isChecked());
	s.writeEntry("/lipstikstyle/Settings/paintGroove", paintGroove->isChecked());
	s.writeEntry("/lipstikstyle/Settings/sharperMenuGradient", sharperMenuGradient->isChecked());
	s.writeEntry("/lipstikstyle/Settings/menuLeftSideBar", menuLeftSideBar->isChecked());
	s.writeEntry("/lipstikstyle/Settings/drawStatusBarFrame", drawStatusBarFrame->isChecked());
	s.writeEntry("/lipstikstyle/Settings/drawToolBarHandle", drawToolBarHandle->isChecked());
	s.writeEntry("/lipstikstyle/Settings/comboboxColored", comboboxColored->isChecked());
	s.writeEntry("/lipstikstyle/Settings/kickerHighlight", kickerHighlight->isChecked());

	s.writeEntry("/lipstikstyle/Settings/scrollBarStyle", scrollBarType(scrollBarStyle->currentItem()));
	s.writeEntry("/lipstikstyle/Settings/sliderStyle", sliderType(sliderStyle->currentItem()));

	s.writeEntry("/lipstikstyle/Settings/animateProgressBar", animateProgressBar->isChecked());
	s.writeEntry("/lipstikstyle/Settings/drawToolBarSeparator", drawToolBarSeparator->isChecked());

	s.writeEntry("/lipstikstyle/Settings/largeGap", largeGap->isChecked());

	s.writeEntry("/lipstikstyle/Settings/drawToolBarItemSeparator", drawToolBarItemSeparator->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/drawFocusRect", drawFocusRect->isChecked());

 	s.writeEntry("/lipstikstyle/Settings/newKickerButtons", newKickerButtons->isChecked());
 	s.writeEntry("/lipstikstyle/Settings/flatHeaders", flatHeaders->isChecked());

	s.writeEntry("/lipstikstyle/Settings/drawTriangularExpander", drawTriangularExpander->isChecked());
	s.writeEntry("/lipstikstyle/Settings/inputFocusHighlight", inputFocusHighlight->isChecked());
	s.writeEntry("/lipstikstyle/Settings/customOverHighlightColor", customOverHighlightColor->isChecked());
	s.writeEntry("/lipstikstyle/Settings/overHighlightColor", QColor(overHighlightColor->color()).name());

	s.writeEntry("/lipstikstyle/Settings/customMenuStripeColor", customMenuStripeColor->isChecked());
	s.writeEntry("/lipstikstyle/Settings/menuStripeColor", QColor(menuStripeColor->color()).name());

	s.writeEntry("/lipstikstyle/Settings/customFocusHighlightColor", customFocusHighlightColor->isChecked());
	s.writeEntry("/lipstikstyle/Settings/focusHighlightColor", QColor(focusHighlightColor->color()).name());
	s.writeEntry("/lipstikstyle/Settings/customCheckMarkColor", customCheckMarkColor->isChecked());
	s.writeEntry("/lipstikstyle/Settings/checkMarkColor", QColor(checkMarkColor->color()).name());
}

void LipstikStyleConfig::defaults()
{
// 	scrollBarLines->setChecked(false);
	reverseGradients->setChecked(false);

//	useAlterHandle->setChecked(false);
	paintGroove->setChecked(true);
	sharperMenuGradient->setChecked(false);
	menuLeftSideBar->setChecked(true);
	drawStatusBarFrame->setChecked(false);
	drawToolBarHandle->setChecked(true);
	comboboxColored->setChecked(false);
	kickerHighlight->setChecked(true);
	
	scrollBarStyle->setCurrentItem(0);
	sliderStyle->setCurrentItem(1);

	animateProgressBar->setChecked(true);
	drawToolBarSeparator->setChecked(false);

	largeGap->setChecked(false);

	drawToolBarItemSeparator->setChecked(true);
 	drawFocusRect->setChecked(false);

 	newKickerButtons->setChecked(false);
 	flatHeaders->setChecked(true);

	drawTriangularExpander->setChecked(true);
	inputFocusHighlight->setChecked(true);
	customOverHighlightColor->setChecked(false);
	overHighlightColor->setColor("black");

	customMenuStripeColor->setChecked(false);
	menuStripeColor->setColor("black");

	customFocusHighlightColor->setChecked(false);
	focusHighlightColor->setColor("black");
	customCheckMarkColor->setChecked(false);
	checkMarkColor->setColor("black");
	//updateChanged would be done by setChecked already
}

void LipstikStyleConfig::updateChanged()
{
	if ( customOverHighlightColor->isChecked() )
	 overHighlightColor->setEnabled(true);
	else
	 overHighlightColor->setEnabled(false);

//Stripe
	if ( menuLeftSideBar->isChecked() ) {
	    customMenuStripeColor->setEnabled(true);
	    if ( customMenuStripeColor->isEnabled() )
		menuStripeColor->setEnabled(true);
	    else
		menuStripeColor->setEnabled(false);
	} else {
	    customMenuStripeColor->setEnabled(false);
	    menuStripeColor->setEnabled(false);
	}
	
	if ( customMenuStripeColor->isChecked() && customMenuStripeColor->isEnabled() )
	 menuStripeColor->setEnabled(true);
	else
	 menuStripeColor->setEnabled(false);

//New style kicker taskbar buttons (KDE 3.5)
	if ( newKickerButtons->isChecked() )
	 kickerHighlight->setEnabled(false);

//Input Focus
	if ( inputFocusHighlight->isChecked() ) {
	    customFocusHighlightColor->setEnabled(true);
	    if ( customFocusHighlightColor->isEnabled() )
		focusHighlightColor->setEnabled(true);
	    else
		focusHighlightColor->setEnabled(false);
	} else {
	    customFocusHighlightColor->setEnabled(false);
	    focusHighlightColor->setEnabled(false);
	}

	if ( customFocusHighlightColor->isChecked() && customFocusHighlightColor->isEnabled() )
	 focusHighlightColor->setEnabled(true);
	else
	 focusHighlightColor->setEnabled(false);

	if ( customCheckMarkColor->isChecked() )
	 checkMarkColor->setEnabled(true);
	else
	 checkMarkColor->setEnabled(false);

	if (/*(scrollBarLines->isChecked() == origScrollBarLines) &&*/
	    (animateProgressBar->isChecked() == origAnimProgressBar) &&
	    (reverseGradients->isChecked() == origReverseGradients) &&
	    
//	    (useAlterHandle->isChecked() == origUseAlterHandle) &&
	    (paintGroove->isChecked() == origPaintGroove) &&
	    (sharperMenuGradient->isChecked() == origSharperMenuGradient) &&
	    (menuLeftSideBar->isChecked() == origMenuLeftSideBar) &&
	    (drawStatusBarFrame->isChecked() == origDrawStatusBarFrame) &&
	    (drawToolBarHandle->isChecked() == origDrawToolBarHandle) &&
	    (comboboxColored->isChecked() == origComboboxColored) &&
	    (kickerHighlight->isChecked() == origKickerHighlight) &&
	    
	    (drawToolBarSeparator->isChecked() == origDrawToolBarSeparator) &&
	    (largeGap->isChecked() == origLargeGap) &&
	    (drawToolBarItemSeparator->isChecked() == origDrawToolBarItemSeparator) &&
 	    (drawFocusRect->isChecked() == origDrawFocusRect) &&

 	    (newKickerButtons->isChecked() == origNewKickerButtons) &&
 	    (flatHeaders->isChecked() == origFlatHeaders) &&

	    (drawTriangularExpander->isChecked() == origDrawTriangularExpander) &&
	    (inputFocusHighlight->isChecked() == origInputFocusHighlight) &&
	    (customOverHighlightColor->isChecked() == origCustomOverHighlightColor) &&
	    (overHighlightColor->color() == origOverHighlightColor) &&

	    (customMenuStripeColor->isChecked() == origCustomMenuStripeColor) &&
	    (menuStripeColor->color() == origMenuStripeColor) &&

	    (customFocusHighlightColor->isChecked() == origCustomFocusHighlightColor) &&
	    (focusHighlightColor->color() == origFocusHighlightColor) &&
	    (customCheckMarkColor->isChecked() == origCustomCheckMarkColor) &&
	    (checkMarkColor->color() == origCheckMarkColor) &&
	    (scrollBarStyle->currentText() == origScrollBarStyle) &&
	    (sliderStyle->currentText() == origSliderStyle)
	)
	    emit changed(false);
	else
	    emit changed(true);
}

void LipstikStyleConfig::colorChanged()
{
	    emit changed(true);
}

//Scrollbar types
QString LipstikStyleConfig::scrollBarType( int listnr )
{
    switch ( listnr ) {
        case 0:
            return QString("WindowsStyleScrollBar");
        case 1:
            return QString("PlatinumStyleScrollBar");
	case 2:
	    return QString("ThreeButtonScrollBar");
	case 3:
	    return QString("NextStyleScrollBar");
	default:
	    return QString("ThreeButtonScrollBar");
    }
}

int LipstikStyleConfig::scrollBarItem( QString kSBType )
{
    if( !strcmp(kSBType,"WindowsStyleScrollBar") )
        return 0;
    else if( !strcmp(kSBType,"PlatinumStyleScrollBar") )
        return 1;
    else if( !strcmp(kSBType,"NextStyleScrollBar") )
        return 3;
    else
        return 2;
}

//Slider types
int LipstikStyleConfig::sliderItem( QString kSliderType )
{
    if( !strcmp(kSliderType,"sliderPlastikStyle") )
        return 0;
    else if( !strcmp(kSliderType,"sliderLipstikStyle") )
        return 1;
    else if( !strcmp(kSliderType,"sliderGtkStyle") )
        return 2;
    else
        return 1;
}

QString LipstikStyleConfig::sliderType( int sliderlistnr )
{
    switch ( sliderlistnr ) {
        case 0:
            return QString("sliderPlastikStyle");
        case 1:
            return QString("sliderLipstikStyle");
	case 2:
	    return QString("sliderGtkStyle");
	default:
	    return QString("sliderLipstikStyle");
    }
}


#include "lipstikconf.moc"
